@@ -54,6 +54,10 @@ def filterNGrams(ngram_path):
                         if i not in spells:
                             bad_word_check = True
                             break
+                    if l[0][0] == l[0][1]:
+                        bad_word_check = True
+                    if l[0][1] == l[0][2]:
+                        bad_word_check = True
                     if bad_word_check:
                         continue
                     outfile.write('\t'.join([' '.join(l[0]),l[1]]))
